Actions, Resources, and Condition Keys for Amazon Kinesis - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Kinesis.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for Amazon Kinesis

Amazon Kinesis (service prefix: `kinesis`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Kinesis
- Resources Defined by Amazon Kinesis
- Condition Keys for Amazon Kinesis

## Actions Defined by Amazon Kinesis

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AddTagsToStream | Adds or updates tags for the specified Amazon Kinesis stream. Each stream can have up to 10 tags. | Tagging | stream* |  |
CreateStream | Creates a Amazon Kinesis stream. | Write | stream* |  |
DecreaseStreamRetentionPeriod | Decreases the stream's retention period, which is the length of time data records are accessible after they are added to the stream. | Write | stream* |  |
DeleteStream | Deletes a stream and all its shards and data. | Write | stream* |  |
DeregisterStreamConsumer | Deregisters a stream consumer with a Kinesis data stream. | Write | consumer* |  |
stream* |  |
DescribeLimits | Describes the shard limits and usage for the account. | Read |  |  |
DescribeStream | Describes the specified stream. | Read | stream* |  |
DescribeStreamConsumer | Gets the description of a registered stream consumer. | Read | consumer* |  |
stream* |  |
DescribeStreamSummary | Provides a summarized description of the specified Kinesis data stream without the shard list. | Read | stream* |  |
DisableEnhancedMonitoring | Disables enhanced monitoring. | Write |  |  |
EnableEnhancedMonitoring | API_EnableEnhancedMonitoring.html | Write |  |  |
GetRecords | Gets data records from a shard. | Read | stream* |  |
GetShardIterator | Gets a shard iterator. A shard iterator expires five minutes after it is returned to the requester. | Read | stream* |  |
IncreaseStreamRetentionPeriod | Increases the stream's retention period, which is the length of time data records are accessible after they are added to the stream. | Write | stream* |  |
ListShards | Lists the shards in a stream and provides information about each shard. | List |  |  |
ListStreamConsumers | Lists the stream consumers registered to receive data from a Kinesis stream using enhanced fan-out, and provides information about each consumer. | List |  |  |
ListStreams | Lists your streams. | List |  |  |
ListTagsForStream | Lists the tags for the specified Amazon Kinesis stream. | Read | stream* |  |
MergeShards | Merges two adjacent shards in a stream and combines them into a single shard to reduce the stream's capacity to ingest and transport data. | Write | stream* |  |
PutRecord | Writes a single data record from a producer into an Amazon Kinesis stream. | Write | stream* |  |
PutRecords | Writes multiple data records from a producer into an Amazon Kinesis stream in a single call (also referred to as a PutRecords request). | Write | stream* |  |
RegisterStreamConsumer | Registers a stream consumer with a Kinesis data stream. | Write | consumer* |  |
stream* |  |
RemoveTagsFromStream | Description for SplitShard | Tagging | stream* |  |
SplitShard | Description for SplitShard | Write | stream* |  |
SubscribeToShard | Listening to a specific shard with enhanced fan-out. | Read | consumer* |  |
stream* |  |
UpdateShardCount | Updates the shard count of the specified stream to the specified number of shards. | Write |  |  |

## Resources Defined by Amazon Kinesis

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
stream | `arn:${Partition}:kinesis:${Region}:${Account}:stream/${StreamName}` |
consumer | `arn:${Partition}:kinesis:${Region}:${Account}:${StreamType}/${StreamName}/consumer/${ConsumerName}:${ConsumerCreationTimpstamp}` |

## Condition Keys for Amazon Kinesis

Kinesis has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference.

On this page:

- Actions Defined by Amazon Kinesis
- Resources Defined by Amazon Kinesis
- Condition Keys for Amazon Kinesis

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more